#!/bin/sh


. /usr/local/packages/netrexcamstreamer/_paths.sh

process_upload() {
  read boundary
  read disposition
  read junk
  read target
   
  a=${#boundary}
  b=${#disposition}
  j=${#junk}
  d=${#target}
  garbageLength=$((a+b+j+d+4))  #count only first boundary

  read boundary
  read disposition
  read ctype
  read junk
   
  a=${#boundary}
  b=${#disposition}
  c=${#ctype}
  j=${#junk}

  filename=${disposition##*filename=\"}
  filename=${filename%%\"*}

  garbageLength=$((garbageLength+a*2+b+j+c+4+3+2))   # +3 bytes after last boundary  +2 magic const :o)

  SIZE=$((CONTENT_LENGTH-garbageLength))

  target=`echo $target | tr -d "\r"`
  path_dir="`get_user_audio_storage_path $target`"
  mkdir -p $path_dir
  head -c $SIZE >"$path_dir/$filename"

  forwardurl "/local/netrexcamstreamer/upload_audio.html" 0
  exit
}

print_file_list() {
  flash_path=`get_user_audio_storage_path "flash"`
  sd0_path=`get_user_audio_storage_path "SD0"`
  flash_files=`ls -AQ1d $flash_path/* | grep -i "\.[mp3|mka]*\"$" | tr -s "\n" ','` 2> /dev/null
  sd0_files=`ls -AQ1d $sd0_path/* | grep -i "\.[mp3|mka]*\"$" | tr -s "\n" ','` 2> /dev/null
  all_files=`echo $flash_files $sd0_files`
  all_files=${all_files%,}  
  echo "Content-Type: text/plain"
  echo "" 
  echo "[$all_files]"
}

remove_file() {
  can_remove="NO"
  filename=`echo "$QUERY_STRING" | sed -n 's/^.*filename=\([^&]*\).*$/\1/p'`
  filename=`urldecode "$filename"`
  if [ `check_allowed_path $filename` -eq 1 ]; then
    rm -f "$filename"
    echo "Content-Type: text/plain"
    echo ""
    echo "1"
    exit
  fi
  echo "Content-Type: text/plain"
  echo ""
  echo "0"
  exit
}

get_storage() {
  free_internal=`df -P | grep /mnt/flash | tr -s " " | cut -d' ' -f4`
  LIMIT=$((free_internal / 1024 / 2))
  flash_path=`get_user_audio_storage_path "flash"`
  if [ `is_path_writable "$flash_path"` -eq 1 ] ; then
    flash_storage="\"flash\": \"Internal memory (Max $LIMIT MB)\""
  else
    flash_storage="\"flash\": \"Internal memory (non-writable)\""
  fi

  sd0_path=`get_user_audio_storage_path "SD0"`
  if mount | grep SD_DISK >/dev/null; then
    if [ `is_path_writable "$sd0_path"` -eq 1 ] ; then
      sd0_storage="\"SD0\": \"SD Disk\""
    else
      sd0_storage="\"SD0\": \"SD Disk (non-writable)\""
    fi
  fi

  echo "Content-Type: text/plain"
  echo ""
  echo -n "{$flash_storage"
  if [ ! -z "$sd0_storage" ] ; then
    echo -n ", $sd0_storage"
  fi
  echo -n "}"

}

is_path_writable() {
  mkdir -p "$1"
  if [ -w "$1" ] ; then  
    echo 1; 
    exit;
  fi
  echo 0;
  exit;
}

get_user_audio_storage_path() {
  if [ "$1" = "flash" ] ; then
    echo "$PATH_USER_AUDIO_FLASH"
    exit
  fi
  if [ "$1" = "SD0" ] ; then
    echo "$PATH_USER_AUDIO_SD"
    exit
  fi
}

check_allowed_path() {
  #this doesnt check for '..' in path
  flash_path=`get_user_audio_storage_path "flash"`
  sd0_path=`get_user_audio_storage_path "SD0"`
  if echo $1 | grep -e "^$flash_path" >/dev/null; then
    echo 1
    exit
  fi
  if echo $1 | grep -e "^$sd0_path" >/dev/null; then
    echo 1
    exit
  fi
  echo 0
  exit
}

urldecode() {
   echo $1 | sed 's@+@ @g;s@%@\\x@g' | xargs printf "%b"
}

action=`echo "$QUERY_STRING" | sed -n 's/^.*action=\([^&]*\).*$/\1/p'`

case $action in
  "list") print_file_list; exit;;
  "remove") remove_file; exit;;
  "upload") process_upload; exit;;
  "get_storage") get_storage; exit;;
esac

echo "Content-Type: text/plain"
echo ""
echo "No action"



   
